@@ -55,10 +55,10 @@ sub go
     $opts->{'skip-tests-for'} = [];
   }
   $opts->{'skip-tests-for'}
-    = { map { $_ => 1 } @{ $opts->{'skip-tests-for'} } };
+      = { map { $_ => 1 } @{ $opts->{'skip-tests-for'} } };
 
   my $unsafe_inc
-    = exists $ENV{PERL_USE_UNSAFE_INC} ? $ENV{PERL_USE_UNSAFE_INC} : 1;
+      = exists $ENV{PERL_USE_UNSAFE_INC} ? $ENV{PERL_USE_UNSAFE_INC} : 1;
 
   # trick AutoInstall
   local $ENV{PERL5_CPAN_IS_RUNNING}     = $$;
@@ -133,11 +133,13 @@ sub go
     info( $target->{src_name}, $line );
     my $method = $states[ $target->{state} ];
     unshift @targets, $method->( $target, $cache );
-    $target->{state}++;
+    $target->{state}++
+        if $target->{state} ne $COMPLETE;
 
     if ( $target->{state} eq scalar @states )
     {
       _complete($target);
+      $target->{was_installed} = 1;
       success( $target->{src_name}, $line );
     }
   }
@@ -163,11 +165,16 @@ sub _resolve
     my $module = $target->{module};
     my $ver    = _get_mod_ver($module);
 
+    my $msg = 'Up to date';
+
+    $msg = 'Installed'
+        if $target->{was_installed};
+
     if ( defined $ver && $target->{version} eq $ver )
     {
       success(
         $target->{src_name},
-        sprintf( '%-13s %s', 'Up to date', $target->{src_name} )
+        sprintf( '%-13s %s', "$msg-", $target->{src_name} )
       );
       _complete($target);
       return;
@@ -184,7 +191,7 @@ sub _resolve
       {
         success(
           $target->{src_name},
-          sprintf( '%-13s %s', 'Up to date', $target->{src_name} )
+          sprintf( '%-13s %s', "$msg=", $target->{src_name} )
         );
         _complete($target);
         return;
@@ -200,7 +207,7 @@ sub _resolve
     $src_dir = $files[0];
   }
 
-  @{$target}{qw/src_tgz dir/} = ( $src_tgz, $src_dir );
+  @{$target}{qw/src_tgz dir was_installed/} = ( $src_tgz, $src_dir, 0 );
   return $target;
 }
 
@@ -250,7 +257,7 @@ sub _configure
   {
     run( $^X, 'Build.PL' );
     my $configured = -e -f 'Build';
-    die 'Unable to configure Buid.PL'
+    die 'Unable to configure Buid.PL for ' . $target->{module}
         unless $configured;
     $maker = 'mb';
   }
@@ -259,12 +266,12 @@ sub _configure
   {
     run( $^X, 'Makefile.PL' );
     my $configured = -e 'Makefile';
-    die 'Unable to configure Makefile.PL'
+    die 'Unable to configure Makefile.PL for ' . $target->{module}
         unless $configured;
     $maker = 'mm';
   }
 
-  die 'Unable to configure'
+  die 'Unable to configure ' . $target->{module}
       if !defined $maker;
 
   $target->{maker} = $maker;
@@ -445,7 +452,7 @@ sub _create_target
   if ( exists $cache->{targets}->{ $target->{src_name} } )
   {
     my $cached_target = $cache->{targets}->{ $target->{src_name} };
-    if ( $cached_target->{state} == $COMPLETE
+    if ( $cached_target->{state} eq $COMPLETE
       && $target->{constraint} ne $cached_target->{constraint} )
     {
       $cached_target->{constraint} = $target->{constraint};
@@ -474,12 +481,12 @@ sub _search_metacpan
   local $File::Fetch::WARN;
   my $ff = File::Fetch->new( uri => $dnld );
   $ff->scheme('http')
-    if $ff->scheme eq 'https';
+      if $ff->scheme eq 'https';
   my $json_info = '';
   my $where = $ff->fetch( to => \$json_info );
 
   die "Could not find module $src on metacpan"
-    if !defined $where;
+      if !defined $where;
 
   return JSON::PP::decode_json($json_info);
 }
@@ -503,7 +510,7 @@ sub _get_targz
     my ( $git_url, $commit ) = $src =~ m/^ (.*?) (?: @ ([^@]*) )? $/xms;
 
     my $dir
-      = tempdir( TEMPLATE => File::Spec->tmpdir . '/mechacpan_XXXXXXXX' );
+        = tempdir( TEMPLATE => File::Spec->tmpdir . '/mechacpan_XXXXXXXX' );
     my ( $fh, $file ) = tempfile(
       TEMPLATE => File::Spec->tmpdir . '/mechacpan_tar.gz_XXXXXXXX',
       CLEANUP  => 1
@@ -569,10 +576,10 @@ sub _get_targz
     my $dest_dir = dest_dir() . "/pkgs";
 
     $ff->scheme('http')
-      if $ff->scheme eq 'https';
+        if $ff->scheme eq 'https';
     my $where = $ff->fetch( to => $dest_dir );
     die $ff->error || "Could not download $url"
-      if !defined $where;
+        if !defined $where;
 
     return $where;
   }
@@ -591,7 +598,7 @@ sub _get_mod_ver
     MM->parse_version($file);
   };
 
-  if (!defined $ver)
+  if ( !defined $ver )
   {
     $ver = $Module::CoreList::version{$]}{$module};
   }
@@ -641,7 +648,7 @@ sub _phase_prereq
     }
 
     push @result, [ $module, $reqs->{$module} ]
-      if $module ne 'perl' && !$is_core;
+        if $module ne 'perl' && !$is_core;
   }
 
   return @result;
@@ -705,7 +712,7 @@ sub _source_translate
   if ( $opts->{'only-sources'} )
   {
     die "Unable to locate $src_name from the sources list\n"
-      if !$new_src;
+        if !$new_src;
     return $new_src;
   }
 
